---
search:
  exclude: true
---
# リリースプロセス/変更履歴

本プロジェクトは、`0.Y.Z` という形式の、やや修正したセマンティック バージョニングに従います。先頭の 0 は、 SDK が依然として急速に進化していることを示します。各コンポーネントは以下のように増分します。

## マイナー (`Y`) バージョン

ベータとしてマークされていない公開インターフェースに対する **破壊的変更** がある場合、マイナー バージョン `Y` を上げます。たとえば、`0.0.x` から `0.1.x` への変更には、破壊的変更が含まれる可能性があります。

破壊的変更を避けたい場合は、プロジェクトで 0.0.x バージョンに固定することをお勧めします。

## パッチ (`Z`) バージョン

非破壊的な変更については `Z` を増分します。

- バグ修正
- 新機能
- 非公開インターフェースの変更
- ベータ機能の更新

## 破壊的変更の変更履歴

### 0.2.0

このバージョンでは、これまで引数として `Agent` を受け取っていた一部の箇所が、代わりに引数として `AgentBase` を受け取るようになりました。たとえば、 MCP サーバーでの `list_tools()` 呼び出しです。これは純粋に型に関する変更であり、引き続き `Agent` オブジェクトを受け取ります。更新するには、`Agent` を `AgentBase` に置き換えて型エラーを修正するだけで済みます。

### 0.1.0

このバージョンでは、[`MCPServer.list_tools()`][agents.mcp.server.MCPServer] に新しいパラメーターが 2 つ追加されました: `run_context` と `agent`。`MCPServer` をサブクラス化しているすべてのクラスに、これらのパラメーターを追加する必要があります。